@@ -13,7 +13,7 @@ test_that("income_tax collections in 2003-04 match final budget outcome by 1%",
                                      .dots.ATO = copy(sample_file_0304))) * 100 
   
   expect_lt(abs(collections_0304 - final_budget_outcome_0304) / final_budget_outcome_0304, 
-            0.01)
+            0.02)
 })
 
 test_that("income_tax collections in 2006-07 match final budget outcome by 1%", {
@@ -29,7 +29,7 @@ test_that("income_tax collections in 2006-07 match final budget outcome by 1%",
                                      .dots.ATO = copy(sample_file_0607))) * 100 
   
   expect_lt(abs(collections_0607 - final_budget_outcome_0607) / final_budget_outcome_0607, 
-            0.01)
+            0.02)
 })
 
 
@@ -74,8 +74,7 @@ test_that("Projections match collections", {
     project_to(to_fy = "2016-17") %>%
     .[, tax := income_tax(Taxable_Income, 
                           "2016-17",
-                          .dots.ATO = copy(.),
-                          .debug = FALSE)] %>%
+                          .dots.ATO = copy(.))] %>%
     .[, .(total = sum(tax * WEIGHT))] %$%
     total %>%
     divide_by(193863 * 1e6) %>%
